@@ -7,8 +7,8 @@ from pyplumio.const import ATTR_PASSWORD
 from pyplumio.frames import FrameTypes, Response
 from pyplumio.helpers.typing import DeviceDataType, MessageType
 from pyplumio.structures.alerts import AlertsStructure
-from pyplumio.structures.boiler_parameters import BoilerParametersStructure
 from pyplumio.structures.data_schema import DataSchemaStructure
+from pyplumio.structures.ecomax_parameters import EcomaxParametersStructure
 from pyplumio.structures.mixer_parameters import MixerParametersStructure
 from pyplumio.structures.network_info import NetworkInfoStructure
 from pyplumio.structures.product_info import ProductInfoStructure
@@ -73,20 +73,20 @@ class PasswordResponse(Response):
         return {ATTR_PASSWORD: password}
 
 
-class BoilerParametersResponse(Response):
-    """Represents boiler parameters response. Contains editable boiler
+class EcomaxParametersResponse(Response):
+    """Represents ecomax parameters response. Contains editable ecomax
     parameters.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_BOILER_PARAMETERS
+    frame_type: ClassVar[int] = FrameTypes.RESPONSE_ECOMAX_PARAMETERS
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
-        return BoilerParametersStructure(self).encode(data)
+        return EcomaxParametersStructure(self).encode(data)
 
     def decode_message(self, message: MessageType) -> DeviceDataType:
         """Decode frame message."""
-        return BoilerParametersStructure(self).decode(message)[0]
+        return EcomaxParametersStructure(self).decode(message)[0]
 
 
 class MixerParametersResponse(Response):
@@ -113,12 +113,12 @@ class DataSchemaResponse(Response):
         return DataSchemaStructure(self).decode(message)[0]
 
 
-class SetBoilerParameterResponse(Response):
-    """Represents set boiler parameter response. Empty response
-    that aknowledges, that boiler parameter was successfully changed.
+class SetEcomaxParameterResponse(Response):
+    """Represents set ecoMAX parameter response. Empty response
+    that aknowledges, that ecoMAX parameter was successfully changed.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_SET_BOILER_PARAMETER
+    frame_type: ClassVar[int] = FrameTypes.RESPONSE_SET_ECOMAX_PARAMETER
 
 
 class SetMixerParameterResponse(Response):
@@ -129,13 +129,13 @@ class SetMixerParameterResponse(Response):
     frame_type: ClassVar[int] = FrameTypes.RESPONSE_SET_MIXER_PARAMETER
 
 
-class BoilerControlResponse(Response):
-    """Represents boiler control response. Empty response
-    that aknowledges, that boiler control request was successfully
+class EcomaxControlResponse(Response):
+    """Represents ecoMAX control response. Empty response
+    that aknowledges, that ecoMAX control request was successfully
     processed.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_BOILER_CONTROL
+    frame_type: ClassVar[int] = FrameTypes.RESPONSE_ECOMAX_CONTROL
 
 
 class AlertsResponse(Response):
