@@ -2,19 +2,28 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from enum import IntEnum, unique
 from typing import Optional
 
 
+@unique
+class ProductTypes(IntEnum):
+    """Contains product types."""
+
+    ECOMAX_P = 0
+    ECOMAX_I = 1
+
+
 @dataclass
 class ProductInfo:
     """Represents product info provided by UID response."""
 
-    type: int = 0
-    product: int = 0
-    uid: Optional[str] = None
-    logo: int = 0
-    image: int = 0
-    model: Optional[str] = None
+    type: int
+    product: int
+    uid: str
+    logo: int
+    image: int
+    model: str
 
 
 @dataclass
